Timestamp

Struct Timestamp 

pub struct Timestamp {
    pub t: u128,
}
Default concrete time type used by this crate.

Timestamp stores a time value in u128 nanoseconds.

For custom clocks, implement crate::time::TimePoint on your own type and use it with Registry<T>.

Fields

t: u128

Implementations

Source

impl Timestamp

pub fn now() -> Self

Returns a Timestamp initialized to the current time. This functionality is useful for dynamic transforms.

Examples
use transforms::time::Timestamp;

let now = Timestamp::now();
assert!(now.t > 0);
Panics

Panics if the system time is earlier than UNIX_EPOCH (January 1, 1970).

pub fn zero() -> Self

Returns a Timestamp initialized at zero. This functionality is especially useful for static transforms.

Examples
use transforms::time::Timestamp;

let zero = Timestamp::zero();
assert_eq!(zero.t, 0);
pub fn as_seconds(&self) -> Result<f64, TimeError>

Converts the Timestamp to seconds as a floating-point number.

Returns an error if the conversion results in accuracy loss.

Examples
use transforms::time::Timestamp;

let timestamp = Timestamp { t: 1_000_000_000 };
let result = timestamp.as_seconds();
assert!(result.is_ok());
assert_eq!(result.unwrap(), 1.0);

let timestamp = Timestamp {
    t: 1_000_000_000_000_000_001,
};
let result = timestamp.as_seconds();
assert!(result.is_err());
Errors

Returns TimeError::AccuracyLoss if the conversion is not exact.

pub fn as_seconds_unchecked(&self) -> f64

Converts the Timestamp to seconds as a floating-point number without checking for accuracy.

Examples
use transforms::time::Timestamp;

let timestamp = Timestamp {
    t: 1_000_000_000_000_000_001,
};
let seconds = timestamp.as_seconds_unchecked();
assert_eq!(seconds, 1_000_000_000.0);